import { readFileSync } from "fs";

import { config } from "dotenv";
import { default as fetch, Headers } from "node-fetch";

config();

let endpoint = process.env.YOUTRACK_URL;
if (!endpoint) {
    throw "YouTrack's base URL is required.";
}
if (!endpoint.endsWith("/")) {
    endpoint += "/";
}

const token = process.env.YOUTRACK_TOKEN
if (!token) {
    throw "A valid YouTrack access token is required.";
}

let cert = process.env.CERTIFICATE;
if (!cert) {
    const certPath = process.env.CERTIFICATE_FILE;
    if (!certPath) {
        throw "A certificate is required.";
    }
    cert = readFileSync(certPath, { encoding: "utf-8" });
}

let privKey = process.env.PRIVATE_KEY;
if (!privKey) {
    const privKeyPath = process.env.PRIVATE_KEY_FILE;
    if (!privKeyPath) {
        throw "A private key is required.";
    }
    privKey = readFileSync(privKeyPath, { encoding: "utf-8" });
}

const apiEndpoint = endpoint + "api/admin/domainSettings";

function makeAPIHeaders() {
    return {
        Authorization: "Bearer " + token,
        Accept: "application/json",
        "Cache-Control": "no-cache",
        "Content-Type": "application/json"
    };
}

async function execute() {
    const json = JSON.stringify({
        certificates: cert,
        privateKey: privKey
    });
    const res = await fetch(apiEndpoint, {
        method: "POST",
        headers: new Headers(makeAPIHeaders()),
        body: json
    });
    if (res.ok) {
        console.log("Success");
    } else {
        console.error("Unable to update the certificate", res.body);
    }
}

execute();